package me.msoucy.ptures.screens

import com.badlogic.gdx.Gdx
import com.badlogic.gdx.graphics.OrthographicCamera
import ktx.app.KtxScreen
import ktx.graphics.use
import me.msoucy.ptures.*

class LoadingScreen(val game: PTures) : KtxScreen {
    private val camera = OrthographicCamera().apply {
        setToOrtho(false, 800f, 480f)
    }

    override fun render(delta: Float) {
        // Continue loading assets
        game.assets.update()

        camera.update()
        game.batch.projectionMatrix = camera.combined

        game.batch.use {
            game.font.draw(it, "Welcome to Drop!!! ", 100f, 150f)
            if (game.assets.isFinished) {
                game.font.draw(it, "Tap anywhere to begin!", 100f, 100f)
            } else {
                game.font.draw(it, "Loading assets...", 100f, 100f)
            }
        }

        if (Gdx.input.isTouched && game.assets.isFinished) {
            game.addScreen(GameScreen(game))
            game.setScreen<GameScreen>()
            game.removeScreen<LoadingScreen>()
            dispose()
        }
    }

    override fun show() {
        MusicAssets.values().forEach { game.assets.load(it) }
        SoundAssets.values().forEach { game.assets.load(it) }
        TextureAtlasAssets.values().forEach { game.assets.load(it) }
    }
}